@@ -26,3 +26,15 @@ class FEs(Resource):
         db.session.add(new_fe)
         db.session.commit()
         return {}, 201
+
+    def get(self, project_id, fm_id):
+        fes = FeatureEvaluations.query.filter_by(project_id=project_id, fm_id=fm_id)
+        return [
+            dict(
+                fm_id=fe.fm_id,
+                feature_id=fe.feature_id,
+                metric_id=fe.metric_id,
+                value=fe.value
+            )
+            for fe in fes
+        ]
