@@ -24,3 +24,14 @@ class FMs(Resource):
         db.session.add(new_fm)
         db.session.commit()
         return {"fm_id": new_fm.fm_id}, 201
+
+    def get(self, project_id):
+        fms = FeatureMatrices.query.filter_by(project_id=project_id)
+        return [
+            dict(
+                fm_id=fm.fm_id,
+                name=fm.name,
+                note=fm.note
+            )
+            for fm in fms
+        ]
